@@ -103,28 +103,23 @@ func (e ErrCNAMERequired) Error() string {
 // This will halt issuance and indicate to the user that a one-time manual setup is required for the domain.
 func (d *DNSProvider) Present(domain, _, keyAuth string) error {
 	// Compute the challenge response FQDN and TXT value for the domain based on the keyAuth.
-	fqdn, value := dns01.GetRecord(domain, keyAuth)
-
-	effectiveDomain := domain
-	if isCNAME(domain, fqdn) {
-		effectiveDomain = fqdn
-	}
+	info := dns01.GetChallengeInfo(domain, keyAuth)
 
 	// Check if credentials were previously saved for this domain.
-	account, err := d.storage.Fetch(effectiveDomain)
+	account, err := d.storage.Fetch(domain)
 	if err != nil {
 		if errors.Is(err, goacmedns.ErrDomainNotFound) {
 			// The account did not exist.
 			// Create a new one and return an error indicating the required one-time manual CNAME setup.
-			return d.register(effectiveDomain, fqdn)
+			return d.register(domain, info.FQDN)
 		}
 
-		// Errors other than goacmeDNS.ErrDomainNotFound are unexpected.
+		// Errors other than goacmedns.ErrDomainNotFound are unexpected.
 		return err
 	}
 
 	// Update the acme-dns TXT record.
-	return d.client.UpdateTXTRecord(account, value)
+	return d.client.UpdateTXTRecord(account, info.Value)
 }
 
 // CleanUp removes the record matching the specified parameters. It is not
@@ -165,7 +160,3 @@ func (d *DNSProvider) register(domain, fqdn string) error {
 		Target: newAcct.FullDomain,
 	}
 }
-
-func isCNAME(domain, fqdn string) bool {
-	return fmt.Sprintf("_acme-challenge.%s.", domain) != fqdn
-}
